@@ -21,13 +21,12 @@ use HTML::TreeBuilder::XPath;
 use XML::Simple qw(XMLin);
 use BibTeX::Parser qw(new next);
 use IO::File;
-#use Data::Dumper;
 use vars qw($VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS @ISA);
 
 #use LWP::Protocol::https;
-use Data::Dumper;
+#use Data::Dumper;
 
-$VERSION = '0.13';
+$VERSION = '0.14';
 @ISA = qw(Exporter);
 @EXPORT = qw();
 @EXPORT_OK = qw(
@@ -78,11 +77,9 @@ sub _split_duplicates {
   my @refs=@{$self->{refs}};
   
   my @newrefs;
-  my @nodoi_refs;
-  my @duprefs;
   foreach my $ref (@refs) {
     my $doi = $ref->doi();
-    if (!defined($doi) || length($doi)==0) {push @nodoi_refs, $ref; next; }# skip entries with no DOI
+    if (!defined($doi) || length($doi)==0) {push @{$self->{nodoi_refs}}, $ref; next; }# skip entries with no DOI
     my $found = 0;
     foreach my $ref2 (@newrefs) {
       if ($ref2->doi() eq $doi) {
@@ -92,12 +89,10 @@ sub _split_duplicates {
     if (!$found) {
       push @newrefs, $ref;
     } else {
-      push @duprefs, $ref;
+      push @{$self->{duprefs}}, $ref;
     }
   }
   $self->{refs} = \@newrefs;
-  $self->{duprefs} = \@duprefs;
-  $self->{nodoi_refs} = \@nodoi_refs;
 }
 
 sub append {
@@ -203,7 +198,15 @@ sub add_dblp {
   if ($res->is_success) {
     my $xs = XML::Simple->new();
     my $data = $xs->XMLin($res->decoded_content);
-    my @cites = $data->{'r'};
+    my @cites; my @ctemp;
+    if (defined $data->{'r'}) {
+       # a person page
+       @cites = $data->{'r'};
+    } elsif (defined $data->{'article'}) { 
+       # its xml for a single article
+       $ctemp[0] = $data;
+       push @cites, \@ctemp;
+    }
     my $num=0;
     foreach my $c (@{$cites[0]}) {
       $num++; if ($maxnum>0 && $num>$maxnum) {last;}  # mainly for testing
@@ -247,9 +250,12 @@ sub add_dblp {
         $r->_setgenre('article');
       } elsif ($k[0] =~ m/inproceedings/) {
         $r->_setgenre('proceeding');
+      } elsif ($k[0] =~ m/informal/) {
+        $r->_setgenre('preprint');
       } else {
         $r->_setgenre($k[0]);
       }
+      $r->_setdate($cite->{'year'});
       $r->_setatitle($cite->{'title'});
       if (defined $cite->{'journal'}) {
         $r->_setjtitle($cite->{'journal'});
@@ -942,7 +948,7 @@ A simple web interface to Bib::Tools is contained in the examples folder.  This
 
 =head1 VERSION
  
-Ver 0.13
+Ver 0.14
  
 =head1 AUTHOR
  
